Package: assertthat
Title: Easy Pre and Post Assertions
Version: 0.2.1
Authors@R: 
  person("Hadley", "Wickham", , "hadley@rstudio.com", c("aut", "cre"))
Description: An extension to stopifnot() that makes it easy to declare 
    the pre and post conditions that you code should satisfy, while also 
    producing friendly error messages so that your users know what's gone
    wrong.
License: GPL-3
Imports: tools
Suggests: testthat, covr
RoxygenNote: 6.0.1
Collate: 'assert-that.r' 'on-failure.r' 'assertions-file.r'
        'assertions-scalar.R' 'assertions.r' 'base.r'
        'base-comparison.r' 'base-is.r' 'base-logical.r' 'base-misc.r'
        'utils.r' 'validate-that.R'
NeedsCompilation: no
Packaged: 2019-03-21 13:11:01 UTC; hadley
Author: Hadley Wickham [aut, cre]
Maintainer: Hadley Wickham <hadley@rstudio.com>
Repository: CRAN
Date/Publication: 2019-03-21 14:53:46 UTC
