# Generated by roxygen2: do not edit by hand

export("%has_args%")
export("%has_attr%")
export("%has_name%")
export("on_failure<-")
export(are_equal)
export(assert_that)
export(has_args)
export(has_attr)
export(has_extension)
export(has_name)
export(is.count)
export(is.date)
export(is.dir)
export(is.error)
export(is.flag)
export(is.number)
export(is.readable)
export(is.scalar)
export(is.string)
export(is.time)
export(is.writeable)
export(noNA)
export(not_empty)
export(on_failure)
export(see_if)
export(validate_that)
